@@ -337,12 +337,34 @@ h2o.getModel <- function(model_id) {
   allparams$response_column <- NULL
   parameters$ignored_columns <- NULL
   parameters$response_column <- NULL
+
+
+  params_to_select <- list(
+    model_id = "name",
+    response_column = "column_name",
+    training_frame = "name",
+    validation_frame = "name"
+  )
+  params <- list(actual=list(), default=list(), input=list())
+  for (p in json$parameters) {
+    if (p$name %in% names(params_to_select)) {
+      params[["actual"]][[p$name]] <- p[["actual_value"]][[params_to_select[[p$name]]]]
+      params[["default"]][[p$name]] <- p[["default_value"]][[params_to_select[[p$name]]]]
+      params[["input"]][[p$name]] <- p[["input_value"]][[params_to_select[[p$name]]]]
+    } else {
+      params[["actual"]][[p$name]] <- p[["actual_value"]]
+      params[["default"]][[p$name]] <- p[["default_value"]]
+      params[["input"]][[p$name]] <- p[["input_value"]]
+    }
+  }
+
   if (identical("glm", json$algo) && allparams$HGLM) {
     .newH2OModel(Class         = Class,
                  model_id      = model_id,
                  algorithm     = json$algo,
                  parameters    = parameters,
                  allparameters = allparams,
+                 params        = params,
                  have_pojo     = FALSE,
                  have_mojo     = FALSE,
                  model         = model)
@@ -352,6 +374,7 @@ h2o.getModel <- function(model_id) {
                algorithm     = json$algo,
                parameters    = parameters,
                allparameters = allparams,
+               params        = params,
                have_pojo     = json$have_pojo,
                have_mojo     = json$have_mojo,
                model         = model)
